#
# See howto.txt for instructions.
#
# Copyright (c) 2013-2014, PagerDuty, Inc. <info@pagerduty.com>
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
#   * Redistributions of source code must retain the above copyright
#     notice, this list of conditions and the following disclaimer.
#   * Redistributions in binary form must reproduce the above copyright
#     notice, this list of conditions and the following disclaimer in the
#     documentation and/or other materials provided with the distribution.
#   * Neither the name of the copyright holder nor the
#     names of its contributors may be used to endorse or promote products
#     derived from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
#

set -e

# do stuff in the script's directory.
basedir=$(dirname $0)
cd $basedir

# source common variables
. ./make_common.env

if [ -z "$1" -o -z "$2" -o ! -d "$1" -o ! -d "$2" ]; then
    echo "Usage: $0 {path-to-gpg-home} {path-to-package-installation-root}"
    exit 2
fi
gpg_home="$1"
install_root="$2"
rpm_install_root=$install_root/rpm
[ -d "$rpm_install_root" ] || mkdir -p $rpm_install_root

# install required packages.
[ $(sudo rpm -q rpm-build ruby193 createrepo \
        gcc gcc-c++ kernel-devel | \
        grep -vc 'not installed') -eq 7 ] || {
    echo "Installing required packages. This may take a few minutes..."
    sudo yum install -y -q rpm-build createrepo gcc gcc-c++ kernel-devel
    sudo yum install -y -q centos-release-SCL
    sudo yum install -y -q ruby193 ruby193-ruby-devel
    source /opt/rh/ruby193/enable
    CUR_PWD=`pwd`
    echo "Installing rubygems ..."
    cd /tmp
    sudo wget --no-check-certificate https://rubygems.org/rubygems/rubygems-2.6.8.tgz
    sudo tar xzf rubygems-2.6.8.tgz
    cd rubygems-2.6.8
    sudo "LD_LIBRARY_PATH=$LD_LIBRARY_PATH" /opt/rh/ruby193/root/usr/bin/ruby setup.rb
    cd $CUR_PWD
    echo "Done installing."
}
{ gem list fpm | grep fpm >/dev/null ; } || {
    echo "Installing fpm gem..."
    sudo "LD_LIBRARY_PATH=$LD_LIBRARY_PATH" /opt/rh/ruby193/root/usr/bin/gem install -q -v $FPM_VERSION fpm
    echo "Done installing."
}

echo "Setting up GPG information for RPM..."
# fingerprint to use for signing = first fingerprint in GPG keyring
fp=$(gpg --homedir $gpg_home --no-tty --lock-never --fingerprint | \
     grep '=' | \
     head -n1 | \
     cut -d= -f2 | \
     tr -d ' ')
cat >$HOME/.rpmmacros <<EOF
%_signature gpg
%_gpg_path $gpg_home
%_gpg_name $fp
EOF

sh make_package.sh rpm

echo "Creating an installable local package repository..."
cp target/*.rpm $rpm_install_root/
cd $rpm_install_root
# the next command cleanly (re)creates repodata and repodata/*
createrepo --simple-md-filenames .

echo "Local install-worthy repository created at: $rpm_install_root"

exit 0
