#
# Uninstalls the agent.
#
# Copyright (c) 2013-2014, PagerDuty, Inc. <info@pagerduty.com>
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
#   * Redistributions of source code must retain the above copyright
#     notice, this list of conditions and the following disclaimer.
#   * Redistributions in binary form must reproduce the above copyright
#     notice, this list of conditions and the following disclaimer in the
#     documentation and/or other materials provided with the distribution.
#   * Neither the name of the copyright holder nor the
#     names of its contributors may be used to endorse or promote products
#     derived from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
#

. $(dirname $0)/util.sh

set -e
set -x

# get agent to run.
test -n "$(agent_pid)" || start_agent

# uninstall agent.
case $(os_type) in
  debian)
    sudo apt-get -y remove pdagent
    ;;
  redhat)
    sudo yum remove -y pdagent
    ;;
  *)
    echo "Unknown os_type " $(os_type) >&2
    exit 1
esac

# for the 'negative = success' commands below, (i.e. we expect the command to
# fail), we are going to remove the 'set -e' condition, and check the exit code
# ourselves.
set +e

# check uninstallation status -- no components must be present.
# no binaries...
which $BIN_PD_SEND
test $? -ne 0 || exit 1
# no libraries...
python -c "import pdagent; print pdagent.__file__" && exit 1
test $? -ne 0 || exit 1
# no configuration files...
test ! -e $CONFIG_FILE

# ensure that agent is not running.
test -z "$(agent_pid)"
